@@ -33,7 +33,7 @@ from linaro_image_tools.media_create.boards import SnowballSdConfig
 from linaro_image_tools.media_create.boards import SnowballEmmcConfig
 from linaro_image_tools.media_create.boards import SMDKV310Config
 from linaro_image_tools.media_create.boards import OrigenConfig
-from linaro_image_tools.media_create.boards import VexpressA9Config
+from linaro_image_tools.media_create.boards import VexpressConfig
 from linaro_image_tools.media_create.boards import (
     align_up,
     align_partition,
@@ -196,7 +196,7 @@ class AndroidSnowballSdConfig(AndroidBoardConfig, SnowballSdConfig):
     boot_script = 'boot.scr'
     initrd_addr = '0x05000000'
     extra_boot_args_options = (
-        'earlyprintk mem=128M@0 mali.mali_mem=64M@128M hwmem=168M@192M mem=22M@360M mem_issw=1M@383M mem=640M@384M vmalloc=256M')
+        'earlyprintk mem=128M@0 mali.mali_mem=64M@128M hwmem=168M@192M mem=22M@360M mem_issw=1M@383M mem=640M@384M vmalloc=300M')
     _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
     # Snowball uses a custom uboot:
@@ -211,7 +211,7 @@ class AndroidSnowballEmmcConfig(AndroidBoardConfig, SnowballEmmcConfig):
     boot_script = 'boot.scr'
     initrd_addr = '0x05000000'
     extra_boot_args_options = (
-        'earlyprintk mem=128M@0 mali.mali_mem=64M@128M hwmem=168M@192M mem=22M@360M mem_issw=1M@383M mem=640M@384M vmalloc=256M')
+        'earlyprintk mem=128M@0 mali.mali_mem=64M@128M hwmem=168M@192M mem=22M@360M mem_issw=1M@383M mem=640M@384M vmalloc=300M')
     _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
     mmc_option = '0:2'
@@ -337,7 +337,7 @@ class AndroidOrigenConfig(AndroidSamsungConfig, OrigenConfig):
     dtb_name = None
 
 
-class AndroidVexpressA9Config(AndroidBoardConfig, VexpressA9Config):
+class AndroidVexpressConfig(AndroidBoardConfig, VexpressConfig):
     _extra_serial_opts = 'console=tty0 console=ttyAMA0,38400n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA0'
     dtb_name = None
@@ -353,5 +353,6 @@ android_board_configs = {
     'iMX53': AndroidMx53LoCoConfig,
     'mx6qsabrelite': AndroidMx6QSabreliteConfig,
     'origen': AndroidOrigenConfig,
-    'vexpress-a9': AndroidVexpressA9Config,
+    'vexpress': AndroidVexpressConfig,
+    'vexpress-a9': AndroidVexpressConfig,
     }
